NoseApp
=======

Vacancy is open (for russian only): http://hh.ru/vacancy/13540190


Installation
------------

::

  pip install noseapp


About
-----

This is framework for test development with complex logic around and based on nose library.


Features
--------

* application is entry point to test program
* Real suite objects. Yes? It's true! :)
* Installing extensions to expand test program
* Several strategies for async run
* Chain of callbacks to setup, teardown (app, suite, test case)
* Chain of callbacks to pre, post run test case


Links
-----

To see docs: http://pythonhosted.org/noseapp/


We offer our extensions to usage:

* noseapp_selenium - https://pypi.python.org/pypi/noseapp_selenium (for UI testing)
* noseapp_daemon https://pypi.python.org/pypi/noseapp_daemon (for linux daemon testing)
* noseapp_requests https://pypi.python.org/pypi/noseapp_requests (wrapper on requests library)
* noseapp_alchemy - https://pypi.python.org/pypi/noseapp_alchemy (wrapper on sqlalchemy library)
